@@ -397,7 +397,7 @@ class InputData:
         _prepare_output_directory(self.output_directory + '/input_reads')
         
         self.summary_file_path = _prepare_summary_file(self.output_directory)
-        
+        self.reference_sequence_paths = None
         self.RG_ID_dict = {}
         self.unique_RG_IDs = {}
         self.vcf_files = []
@@ -411,6 +411,7 @@ class InputData:
         self.alignment_files = []
         self.phasable_samples = {}
         self.reference_sequence_files = {}
+        
         # self.sample_hap_to_true_alignment_dict = {}
         
         self.reference_sequence_input = reference_sequence_input
@@ -616,6 +617,8 @@ class InputData:
             if sample in self.sample_to_reference_sequence_path:
                 if len(self.sample_to_reference_sequence_path[sample]) > 0:
                     reference_sequence_paths = self.sample_to_reference_sequence_path[sample]
+            else:
+                reference_sequence_paths = self.reference_sequence_paths
             phasable_sample = self.new_PhasableSample(sample, reference_sequence_paths)
             #vcf_file_path, ignore_phase_sets = self._pair_sample_with_vcf(sample, self.sample_to_vcf_file_dict,
             #                                                             self.ignore_phase_sets)
@@ -661,7 +664,7 @@ class InputData:
                 sorted_bam_file_path, combined_long_read_fastq_path = self._parse_long_reads_input(
                         _sorted_bam_file_path, self.output_directory
                         )
-                self.RG_ID_dict, self.unique_RG_IDs = self._compile_read_groups(
+                self.RG_ID_dict, self.unique_RG_IDs = _compile_read_groups(
                         sorted_bam_file_path[0], sample, ID, sample_description, self.RG_ID_dict, self.unique_RG_IDs,
                         self.ignore_samples
                         )
