@@ -70,7 +70,8 @@ def simulate_reads_pbsim2(
                     ) + 'min_' + str(time.localtime()[5]) + 'sec'
         else:
             prefix = '{0}/{1}__{2}__{3}'.format(str(output_directory), str(sample), str(haplotype), str(prefix))
-    
+    else:
+        prefix = '{0}/{1}__{2}__{3}'.format(str(output_directory), str(sample), str(haplotype), str(prefix))
     # if prefix is None:
     # if prefix is None:
     # prefix = str(output_directory) + '/pbsim2_simulated'
@@ -145,8 +146,12 @@ def simulate_reads_pbsim2(
         file = str(os.path.dirname(pbsim2_pbsim2fq_output)) + '/' + str(file)
         if str(file).lower().endswith('pbsim2fq.fastq') or str(file).lower().endswith('pbsim2fq.fastq.gz'):
             continue
+        if str(file).lower().endswith('.maf'):
+            os.remove(file)
+        if str(file).lower().endswith('.ref'):
+            os.remove(file)
         elif str(file).lower().endswith('.fastq'):
-            with open(combined_simulated_long_reads_fastq_path, 'w') as outfile:
+            with open(combined_simulated_long_reads_fastq_path, 'a') as outfile:
                 with open(file, 'r') as infile:
                     outfile.write(infile.read())
             os.remove(file)
@@ -255,7 +260,7 @@ def generate_haplotype_specific_fasta(
         chain_file_path = str(os.path.splitext(input_reference_sequence_path)[0]) + '_hap' + str(haplotype) + '_' + str(
                 sample
                 ) + '.chain'
-    
+        
     fasta_output = bcftools.consensus(
             '-H', str(haplotype), '-s', str(sample), '-c', str(chain_file_path), '-f',
             str(input_reference_sequence_path),
@@ -327,20 +332,19 @@ def create_fasta_file(
             regions_list = all_regions
     
     elif isinstance(regions, list):
-        regions_file: str = str(os.splitext(output_fasta_file_path)[0]) + '_regions.txt'
+        regions_file: str = str(os.path.splitext(output_fasta_file_path)[0]) + '_regions.txt'
         if only_autosomal:
             regions_list = [region for region in regions if region in autosomal_reference_names]
         else:
             regions_list = regions
     
-    if regions is not None:
-        if os.path.isfile(regions):
-            regions_file = regions
-    else:
-        with open(regions_file, 'w') as file:
-            for region in regions_list:
-                file.write(str(region) + '\n')
-    
+    elif os.path.isfile(regions):
+        regions_file = regions
+        
+    with open(regions_file, 'w') as file:
+        for region in regions_list:
+            file.write(str(region) + '\n')
+
     faidx(input_fasta_file_path, '-r', regions_file, '-o', output_fasta_file_path)
     
     return output_fasta_file_path
